Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FromMap ¶ added in v0.2.6
FromMap parses a map and converts it to a struct.
This is just a convenience wrapper that marshals the map to JSON and then unmarshals it to the provided struct type, and is probably wildly inefficient. But it's handy. Like your mom.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.